library(lattice)
library(lme4)
library(emmeans)

# L2 Morphological dataset, local trials, data cleaning and inverse transformation
l2labra <- read.csv('local_trials_morph_L2.csv')
labrainv <- 1/l2labra$rt
l2labra$labrainv <- labrainv
labrarem <- l2labra[l2labra$labrainv < 2.5,]

# Mixed linear model, local trials, L2 Morphological dataset
labra.imm <- lmer(labrainv ~ primetype + relationtype + immersion + (1+relationtype|participant) + (1+primetype|participant) + (1+immersion|participant) + (1|target), data = labrarem,contrasts =  list(relationtype=contr.helmert(2)))


# L2 Morphological dataset, online trials, data cleaning and inverse transformation
l2 <- read.csv('online_trials_morph_L2.csv')
l2inv <- 1/l2$rt
l2$l2inv <- l2inv
l2rem <- l2[l2$l2inv < 2.5,]

# Mixed linear model, online trials, L2 Morphological dataset
malli.imm <- lmer(l2inv ~  relationtype + primetype + immersion + (1+relationtype|participant) + (1+primetype|participant) + (1+immersion|participant) +(1|target), data = l2rem, control = lmerControl(optimizer ="optimx", optCtrl=list(method='nlminb')), contrasts =  list(relationtype=contr.helmert(2)))



# L2 orthographic and semantic datasets, online trials, data cleaning and inverse transformation
ortosem_l2 <- read.csv('ortoseml2.csv')
ortosem_inv <- 1/ortosem_l2$rt
ortosem_l2$ortosem_inv <- ortosem_inv
ortosem_l2rem.2 <- ortosem_l2[ortosem_l2$ortosem_inv < 2.5,]

# Mixed linear model, L2 orthographic and semantic datasets
ortosemmallil2 <- lmer(ortosem_inv ~ relationtype + primetype + immersion + (1+relationtype|participant) + (1+primetype|participant) + (1+immersion|participant) +(1|target2), data = ortosem_l2rem.2, control = lmerControl(optimizer ="optimx", optCtrl=list(method='nlminb')), contrasts =  list(relationtype=contr.helmert(2)))
summary(ortosemmallil2)


# L1 Morphological dataset, online trials, data cleaning and inverse transformation
natiivi <- read.csv('mixed_L1_morph.csv')
natiivi_inv <- 1/natiivi$rt
natiivi$natiivi_inv <- natiivi_inv
natiivi_rem <- natiivi[natiivi$natiivi_inv< 2.5,]

# Mixed linear model, L1 Morphological dataset
nat <- lmer(natiivi_inv ~ primetype + relationtype + (1+relationtype|participant) + (1+primetype|participant) + (1|target), data = natiivi_rem,contrasts =  list(relationtype=contr.sum(2)))
summary(nat)

# L1 orthographic and semantic datasets, online trials, data cleaning and inverse transformation
ortosem_l1 <- read.csv('mixed_semaorto_L1.csv')
ortosem_l1 <- na.omit(ortosem_l1)
ortosem_invl1 <- 1/ortosem_l1$rt
ortosem_l1$ortosem_invl1 <- ortosem_invl1
ortosem_l1rem.25 <- ortosem_l1[ortosem_l1$ortosem_invl1 < 2.5,]

ortomalli_l1 <- lmer(ortosem_invl1 ~ primetype + relationtype +  (1+primetype|participant) + (1+relationtype|participant) + (1|target2), data = ortosem_l1rem.25, contrasts =  list(relationtype=contr.helmert(2)))







